Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(137)

Unified Diff: chrome/browser/engagement/site_engagement_score.h

Issue 2274973003: Enable site engagement in incognito. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: address_nit Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/engagement/site_engagement_score.h
diff --git a/chrome/browser/engagement/site_engagement_score.h b/chrome/browser/engagement/site_engagement_score.h
index 405051376c4f1853ad2f43fb7fb22a6aae3e654c..70619da395e30033b954003eb31e8f43ea47960e 100644
--- a/chrome/browser/engagement/site_engagement_score.h
+++ b/chrome/browser/engagement/site_engagement_score.h
@@ -18,7 +18,7 @@ namespace base {
class Clock;
}
-class HostContentSettingsMap;
+class Profile;
class SiteEngagementScore {
public:
@@ -114,7 +114,7 @@ class SiteEngagementScore {
// SiteEngagementScore.
SiteEngagementScore(base::Clock* clock,
const GURL& origin,
- HostContentSettingsMap* settings_map);
+ Profile* profile);
SiteEngagementScore(SiteEngagementScore&& other);
~SiteEngagementScore();
@@ -218,8 +218,8 @@ class SiteEngagementScore {
// The origin this score represents.
GURL origin_;
- // The settings map to write this score to when Commit() is called.
- HostContentSettingsMap* settings_map_;
+ // The profile to write this score to when Commit() is called.
+ Profile* profile_;
DISALLOW_COPY_AND_ASSIGN(SiteEngagementScore);
};
« no previous file with comments | « chrome/browser/engagement/site_engagement_helper.cc ('k') | chrome/browser/engagement/site_engagement_score.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698